@@ -4,5 +4,5 @@
   packageStartupMessage(paste0("Package: ", pkgname, ", Version: ", RFver))
   packageStartupMessage("Cause-specific Framework for Competing-risk survival analysis")
   packageStartupMessage("School of Public Heath, Imperial College London &")
-  packageStartupMessage("Davidson Kempner Capital Management, NY")
+  packageStartupMessage("New York Stock Exchange, NY")
 }
